-- local addonName, addonTable = ...;

NIButton = {};

local C = NIButton;
local minimapButton = "NIGuiButton";

function C:OnLoad(caller)
    caller:RegisterForDrag("LeftButton");
    caller:RegisterEvent("PLAYER_LOGIN");
end

function C:OnEvent(event, ...)
    local arg = {...};
    NICore:PrintD("EVENT Button! " .. tostring(event));

    if event == "PLAYER_LOGIN" then
        C:OnVariablesLoaded()
    end
end

function C:OnVariablesLoaded()
    local xPos, yPos = NISettings:GetButtonPositions()
    C:RepositionButton(xPos, yPos)
    
    if not NISettings:IsButtonShown() then
        getglobal(minimapButton):Hide();
    end
end

function C:UpdateButton()
    if NISettings:IsButtonShown() then
        C:ShowButton()
    else
        C:HideButton()
    end
end

function C:ShowButton( )
    getglobal(minimapButton):Show();
end

function C:HideButton( )
    getglobal(minimapButton):Hide();
end

function C:OnMouseWheel(delta)
    NIDisplay:EnableDungeonMode()
    if delta > 0 then
        NIDisplay:IncreaseDungeonAlpha( 0.05 )
        -- NICore:PrintD("BUTTON! Increased Dungeon Alpha")
    elseif delta < 0 then
        NIDisplay:DecreaseDungeonAlpha( 0.05 )
        -- NICore:PrintD("BUTTON! Decreased Dungeon Alpha")
    end
    C:SetTooltip(GameTooltip)
end

local function isDraggingModifierDown()
    return IsRightAltKeyDown() or IsLeftAltKeyDown();
end

function C:OnMouseDown(button)
    if isDraggingModifierDown() then
        -- moving
    elseif button == "LeftButton" then -- illuminate
        NISettings:SetIllumination( not NISettings:IsIlluminated() )
    elseif button == "RightButton" then -- dungeonMode
        if NISettings:IsDungeonMode() then
            NIDisplay:DisableDungeonMode()
            NICore:PrintD("BUTTON! Disabled Dungeon Mode")
        else
            NIDisplay:EnableDungeonMode()
            NICore:PrintD("BUTTON! Enabled Dungeon Mode")
        end
    elseif button == "MiddleButton" then -- On/Off
        if NISettings:IsActive() then
            NIDisplay:Disable()
            NICore:PrintD("BUTTON! Disabled NightIllusion")
        else
            NIDisplay:Enable()
            NICore:PrintD("BUTTON! Enabled NightIllusion")
        end
    end
    C:SetTooltip(GameTooltip)
end

function C:Drag_OnUpdate()
    if isDraggingModifierDown() then
        local xPos, yPos = GetCursorPosition();
        local uiScale = UIParent:GetEffectiveScale()
        local uiWidth, uiHeight = UIParent:GetWidth(), UIParent:GetHeight();
        
        xPos = xPos / uiScale - uiWidth / 2;
        yPos = yPos / uiScale - uiHeight / 2;
        
        C:ChangeButtonPosition(xPos, yPos);
    end
end

function C:ChangeButtonPosition(newX, newY)
    C:RepositionButton(newX, newY)
    NISettings:SetButtonPositions(newX, newY)
end

function C:RepositionButton(newX, newY)
    getglobal(minimapButton):SetPoint("CENTER", "UIParent", "CENTER", newX, newY);
end

function C:IsDragged()
    if isDraggingModifierDown() then
        return true;
    else
        return false;
    end
end

function C:OnEnter(frame)
	if (C:IsDragged()) then
		return
	end
	GameTooltip:SetOwner(frame or UIParent, "ANCHOR_CURSOR ")
	C:SetTooltip(GameTooltip)
end

function C:SetTooltip(tooltip)
-- 262971
    if NISettings:IsActive() then
        on = "[ON]";
    else
        on = "[OFF]";
    end

    local colCMD  = NICore.colors.dark;
    local colDesc = NICore.colors.light;
    
    local txt = "|cFF"..colDesc.."NightIllusion: \n\n" 
    ..
    "State: " .. on;
    
    if NISettings:IsActive() then
        if NISettings:IsDungeonMode() then
            txt = txt .. ", " .. NightIllusion_L.DUNGEON;
        else
            txt = txt .. ", " .. NightIllusion_L.AUTOMATIC;
        end
    end
    if NISettings:IsIlluminated() then
        txt = txt .. "\n\n" .. NightIllusion_L.TXT_ILLUMINATED
    end
    
    txt = txt .. "\n\n|cFF" ..colCMD .. 
    "[".. NightIllusion_L.KEY_LEFTBUTTON .. "] " .. NightIllusion_L.TOOLTIP_ILLUMINATE .. "\n" ..
    "[".. NightIllusion_L.KEY_RIGHTBUTTON .. "] " .. NightIllusion_L.TOOLTIP_DUNGEON .. "\n" ..
    "[".. NightIllusion_L.KEY_MIDDLEBUTTON .. "] " .. NightIllusion_L.TOOLTIP_ACTIVATE .. "\n" ..
    "[".. NightIllusion_L.KEY_WHEELUP .. "] " .. NightIllusion_L.TOOLTIP_INCREASE .. "\n" ..
    "[".. NightIllusion_L.KEY_WHEELDOWN .. "] " .. NightIllusion_L.TOOLTIP_DECREASE .. "\n" ..
    "[".. NightIllusion_L.KEY_ALT .. "+" .. NightIllusion_L.KEY_LEFTBUTTON .. "] " .. NightIllusion_L.TOOLTIP_MOVE .. "|r";

	tooltip:SetText(txt)
end